package com.hw.dms.mapper;

import java.util.List;
import com.hw.dms.domain.DmsBaseShutReason;

/**
 * 停机原因信息Mapper接口
 * 
 * @author Open Platform
 * @date 2024-01-12
 */
public interface DmsBaseShutReasonMapper 
{
    /**
     * 查询停机原因信息
     * 
     * @param shutReasonId 停机原因信息主键
     * @return 停机原因信息
     */
    public DmsBaseShutReason selectDmsBaseShutReasonByShutReasonId(Long shutReasonId);

    /**
     * 查询停机原因信息列表
     * 
     * @param dmsBaseShutReason 停机原因信息
     * @return 停机原因信息集合
     */
    public List<DmsBaseShutReason> selectDmsBaseShutReasonList(DmsBaseShutReason dmsBaseShutReason);

    /**
     * 新增停机原因信息
     * 
     * @param dmsBaseShutReason 停机原因信息
     * @return 结果
     */
    public int insertDmsBaseShutReason(DmsBaseShutReason dmsBaseShutReason);

    /**
     * 修改停机原因信息
     * 
     * @param dmsBaseShutReason 停机原因信息
     * @return 结果
     */
    public int updateDmsBaseShutReason(DmsBaseShutReason dmsBaseShutReason);

    /**
     * 删除停机原因信息
     * 
     * @param shutReasonId 停机原因信息主键
     * @return 结果
     */
    public int deleteDmsBaseShutReasonByShutReasonId(Long shutReasonId);

    /**
     * 批量删除停机原因信息
     * 
     * @param shutReasonIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDmsBaseShutReasonByShutReasonIds(Long[] shutReasonIds);
}
