package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsBaseShutReason;
import com.hw.dms.service.IDmsBaseShutReasonService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 停机原因信息Controller
 * 
 * @author Open Platform
 * @date 2024-01-12
 */
@RestController
@RequestMapping("/shutReason")
public class DmsBaseShutReasonController extends BaseController
{
    @Autowired
    private IDmsBaseShutReasonService dmsBaseShutReasonService;

    /**
     * 查询停机原因信息列表
     */
    @RequiresPermissions("dms:shutReason:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseShutReason dmsBaseShutReason)
    {
        startPage();
        List<DmsBaseShutReason> list = dmsBaseShutReasonService.selectDmsBaseShutReasonList(dmsBaseShutReason);
        return getDataTable(list);
    }

    /**
     * 导出停机原因信息列表
     */
    @RequiresPermissions("dms:shutReason:export")
    @Log(title = "停机原因信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseShutReason dmsBaseShutReason)
    {
        List<DmsBaseShutReason> list = dmsBaseShutReasonService.selectDmsBaseShutReasonList(dmsBaseShutReason);
        ExcelUtil<DmsBaseShutReason> util = new ExcelUtil<DmsBaseShutReason>(DmsBaseShutReason.class);
        util.exportExcel(response, list, "停机原因信息数据");
    }

    /**
     * 获取停机原因信息详细信息
     */
    @RequiresPermissions("dms:shutReason:query")
    @GetMapping(value = "/{shutReasonId}")
    public AjaxResult getInfo(@PathVariable("shutReasonId") Long shutReasonId)
    {
        return success(dmsBaseShutReasonService.selectDmsBaseShutReasonByShutReasonId(shutReasonId));
    }

    /**
     * 新增停机原因信息
     */
    @RequiresPermissions("dms:shutReason:add")
    @Log(title = "停机原因信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseShutReason dmsBaseShutReason)
    {
        return toAjax(dmsBaseShutReasonService.insertDmsBaseShutReason(dmsBaseShutReason));
    }

    /**
     * 修改停机原因信息
     */
    @RequiresPermissions("dms:shutReason:edit")
    @Log(title = "停机原因信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseShutReason dmsBaseShutReason)
    {
        return toAjax(dmsBaseShutReasonService.updateDmsBaseShutReason(dmsBaseShutReason));
    }

    /**
     * 删除停机原因信息
     */
    @RequiresPermissions("dms:shutReason:remove")
    @Log(title = "停机原因信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{shutReasonIds}")
    public AjaxResult remove(@PathVariable Long[] shutReasonIds)
    {
        return toAjax(dmsBaseShutReasonService.deleteDmsBaseShutReasonByShutReasonIds(shutReasonIds));
    }
}
